@@ -85,31 +85,42 @@ class NodeConstructor(SafeConstructor):
         # occurance, which can give unexpected results
         mapping = {}
         self.flatten_mapping(node)
+        matches = []
         for key_node, value_node in node.value:
             key = self.construct_object(key_node, False)
             value = self.construct_object(value_node, False)
 
             for key_dup in mapping:
                 if key_dup == key:
-                    raise CfnParseError(
-                        self.filename,
-                        [
+                    if not matches:
+                        matches.extend(
+                            [
+                                build_match(
+                                    filename=self.filename,
+                                    message=f'Duplicate found "{key}" (line {key_dup.start_mark.line + 1})',
+                                    line_number=key_dup.start_mark.line,
+                                    column_number=key_dup.start_mark.column,
+                                    key=key,
+                                ),
+                                build_match(
+                                    filename=self.filename,
+                                    message=f'Duplicate found "{key}" (line {key_node.start_mark.line + 1})',
+                                    line_number=key_node.start_mark.line,
+                                    column_number=key_node.start_mark.column,
+                                    key=key,
+                                ),
+                            ],
+                        )
+                    else:
+                        matches.append(
                             build_match(
                                 filename=self.filename,
-                                message=f'Duplicate resource found "{key}" (line {key_dup.start_mark.line + 1})',
-                                line_number=key_dup.start_mark.line,
-                                column_number=key_dup.start_mark.column,
-                                key=key,
-                            ),
-                            build_match(
-                                filename=self.filename,
-                                message=f'Duplicate resource found "{key}" (line {key_node.start_mark.line + 1})',
+                                message=f'Duplicate found "{key}" (line {key_node.start_mark.line + 1})',
                                 line_number=key_node.start_mark.line,
                                 column_number=key_node.start_mark.column,
                                 key=key,
                             ),
-                        ],
-                    )
+                        )
             try:
                 mapping[key] = value
             except Exception as exc:
@@ -126,6 +137,12 @@ class NodeConstructor(SafeConstructor):
                     ],
                 ) from exc
 
+        if matches:
+            raise CfnParseError(
+                self.filename,
+                matches,
+            )
+
         (obj,) = SafeConstructor.construct_yaml_map(self, node)
 
         if len(mapping) == 1:
@@ -239,8 +256,15 @@ def load(filename):
     content = ''
 
     if not sys.stdin.isatty():
-        for line in fileinput.input(files=filename):
-            content = content + line
+        filename = '-' if filename is None else filename
+        if sys.version_info.major <= 3 and sys.version_info.minor <= 9:
+            for line in fileinput.input(files=filename):
+                content = content + line
+        else:
+            for line in fileinput.input(  # pylint: disable=unexpected-keyword-arg
+                files=filename, encoding='utf-8'
+            ):
+                content = content + line
     else:
         with open(filename, encoding='utf-8') as fp:
             content = fp.read()
