@@ -11,6 +11,7 @@ from cfnlint.helpers import REGEX_CIDR
 
 class Cidr(CloudFormationLintRule):
     """Check if Cidr values are correct"""
+
     id = 'E1024'
     shortdesc = 'Cidr validation of parameters'
     description = 'Making sure the function CIDR is a list with valid values'
@@ -33,22 +34,37 @@ class Cidr(CloudFormationLintRule):
                 for index_key, _ in value.items():
                     if index_key not in self.supported_functions:
                         if index_key == 'Fn::If':
-                            if len(value.get('Fn::If')) == 3 and isinstance(value.get('Fn::If'), list):
-                                matches.extend(self.check_ip_block(value.get('Fn::If')[1], path=path[:] + [index_key , 1]))
-                                matches.extend(self.check_ip_block(value.get('Fn::If')[2], path=path[:] + [index_key , 2]))
+                            if len(value.get('Fn::If')) == 3 and isinstance(
+                                value.get('Fn::If'), list
+                            ):
+                                matches.extend(
+                                    self.check_ip_block(
+                                        value.get('Fn::If')[1],
+                                        path=path[:] + [index_key, 1],
+                                    )
+                                )
+                                matches.extend(
+                                    self.check_ip_block(
+                                        value.get('Fn::If')[2],
+                                        path=path[:] + [index_key, 2],
+                                    )
+                                )
                         else:
                             message = 'Cidr ipBlock should be Cidr Range, Ref, GetAtt, Sub or Select for {0}'
-                            matches.append(RuleMatch(
-                                path, message.format('/'.join(map(str, value)))))
+                            matches.append(
+                                RuleMatch(
+                                    path, message.format('/'.join(map(str, value)))
+                                )
+                            )
         elif isinstance(value, (str)):
             if not re.match(REGEX_CIDR, value):
                 message = 'Cidr ipBlock should be a Cidr Range based string for {0}'
-                matches.append(RuleMatch(
-                    path, message.format('/'.join(map(str, path)))))
+                matches.append(
+                    RuleMatch(path, message.format('/'.join(map(str, path))))
+                )
         else:
             message = 'Cidr ipBlock should be a string for {0}'
-            matches.append(RuleMatch(
-                path, message.format('/'.join(map(str, path)))))
+            matches.append(RuleMatch(path, message.format('/'.join(map(str, path)))))
 
         return matches
 
@@ -60,20 +76,39 @@ class Cidr(CloudFormationLintRule):
                 for index_key, index_value in value.items():
                     if index_key not in self.supported_functions:
                         if index_key == 'Fn::If':
-                            if len(value.get('Fn::If')) == 3 and isinstance(value.get('Fn::If'), list):
-                                matches.extend(self.check_count(value.get('Fn::If')[1], path=path[:] + [index_key , 1]))
-                                matches.extend(self.check_count(value.get('Fn::If')[2], path=path[:] + [index_key , 2]))
+                            if len(value.get('Fn::If')) == 3 and isinstance(
+                                value.get('Fn::If'), list
+                            ):
+                                matches.extend(
+                                    self.check_count(
+                                        value.get('Fn::If')[1],
+                                        path=path[:] + [index_key, 1],
+                                    )
+                                )
+                                matches.extend(
+                                    self.check_count(
+                                        value.get('Fn::If')[2],
+                                        path=path[:] + [index_key, 2],
+                                    )
+                                )
                         else:
                             message = 'Cidr count should be Int, Ref, or Select for {0}'
-                            matches.append(RuleMatch(
-                                path, message.format('/'.join(map(str, path)))))
+                            matches.append(
+                                RuleMatch(
+                                    path, message.format('/'.join(map(str, path)))
+                                )
+                            )
                     if index_key == 'Ref':
                         count_parameters.append(index_value)
         elif not isinstance(value, int):
             message = 'Cidr count should be a int for {0}'
-            extra_args = {'actual_type': type(value).__name__, 'expected_type': int.__name__}
-            matches.append(RuleMatch(
-                path, message.format('/'.join(map(str, path))), **extra_args))
+            extra_args = {
+                'actual_type': type(value).__name__,
+                'expected_type': int.__name__,
+            }
+            matches.append(
+                RuleMatch(path, message.format('/'.join(map(str, path))), **extra_args)
+            )
 
         return count_parameters, matches
 
@@ -85,20 +120,41 @@ class Cidr(CloudFormationLintRule):
                 for index_key, index_value in value.items():
                     if index_key not in self.supported_functions:
                         if index_key == 'Fn::If':
-                            if len(value.get('Fn::If')) == 3 and isinstance(value.get('Fn::If'), list):
-                                matches.extend(self.check_size_mask(value.get('Fn::If')[1], path=path[:] + [index_key , 1]))
-                                matches.extend(self.check_size_mask(value.get('Fn::If')[2], path=path[:] + [index_key , 2]))
+                            if len(value.get('Fn::If')) == 3 and isinstance(
+                                value.get('Fn::If'), list
+                            ):
+                                matches.extend(
+                                    self.check_size_mask(
+                                        value.get('Fn::If')[1],
+                                        path=path[:] + [index_key, 1],
+                                    )
+                                )
+                                matches.extend(
+                                    self.check_size_mask(
+                                        value.get('Fn::If')[2],
+                                        path=path[:] + [index_key, 2],
+                                    )
+                                )
                         else:
-                            message = 'Cidr sizeMask should be Int, Ref, or Select for {0}'
-                            matches.append(RuleMatch(
-                                path, message.format('/'.join(map(str, path)))))
+                            message = (
+                                'Cidr sizeMask should be Int, Ref, or Select for {0}'
+                            )
+                            matches.append(
+                                RuleMatch(
+                                    path, message.format('/'.join(map(str, path)))
+                                )
+                            )
                     if index_key == 'Ref':
                         size_mask_parameters.append(index_value)
         elif not isinstance(value, int):
             message = 'Cidr sizeMask should be a int for {0}'
-            extra_args = {'actual_type': type(value).__name__, 'expected_type': int.__name__}
-            matches.append(RuleMatch(
-                path, message.format('/'.join(map(str, path))), **extra_args))
+            extra_args = {
+                'actual_type': type(value).__name__,
+                'expected_type': int.__name__,
+            }
+            matches.append(
+                RuleMatch(path, message.format('/'.join(map(str, path))), **extra_args)
+            )
 
         return size_mask_parameters, matches
 
@@ -114,16 +170,25 @@ class Cidr(CloudFormationLintRule):
                 min_value = parameter_obj.get('MinValue')
                 if (not min_value) or min_value < 1 or min_value > 256:
                     message = 'Parameter for Cidr count have MinValue between 1 and 256 at {0}'
-                    matches.append(RuleMatch(
-                        tree + ['MinValue'], message.format('/'.join(map(str, tree + ['MinValue'])))))
+                    matches.append(
+                        RuleMatch(
+                            tree + ['MinValue'],
+                            message.format('/'.join(map(str, tree + ['MinValue']))),
+                        )
+                    )
                 if (not max_value) or max_value < 1 or max_value > 256:
                     message = 'Parameter for Cidr count have MaxValue between 1 and 256 at {0}'
-                    matches.append(RuleMatch(
-                        tree + ['MaxValue'], message.format('/'.join(map(str, tree + ['MaxValue'])))))
+                    matches.append(
+                        RuleMatch(
+                            tree + ['MaxValue'],
+                            message.format('/'.join(map(str, tree + ['MaxValue']))),
+                        )
+                    )
             else:
                 message = 'Parameter for Cidr count have be of Type Number at {0}'
-                matches.append(RuleMatch(
-                    tree, message.format('/'.join(map(str, tree)))))
+                matches.append(
+                    RuleMatch(tree, message.format('/'.join(map(str, tree))))
+                )
 
         return matches
 
@@ -138,19 +203,32 @@ class Cidr(CloudFormationLintRule):
                 max_value = parameter_obj.get('MaxValue')
                 min_value = parameter_obj.get('MinValue')
                 if (not min_value) or min_value < 1 or min_value > 256:
-                    message = 'Parameter for Cidr sizeMask have MinValue between 1 and ' \
+                    message = (
+                        'Parameter for Cidr sizeMask have MinValue between 1 and '
                         '128 (for ipv6) and 32 (for ipv4) at {0}'
-                    matches.append(RuleMatch(
-                        tree + ['MinValue'], message.format('/'.join(map(str, tree + ['MinValue'])))))
+                    )
+                    matches.append(
+                        RuleMatch(
+                            tree + ['MinValue'],
+                            message.format('/'.join(map(str, tree + ['MinValue']))),
+                        )
+                    )
                 if (not max_value) or max_value < 1 or max_value > 256:
-                    message = 'Parameter for Cidr count have MaxValue between 1 and ' \
+                    message = (
+                        'Parameter for Cidr count have MaxValue between 1 and '
                         '128 (for ipv6) and 32 (for ipv4) at {0}'
-                    matches.append(RuleMatch(
-                        tree + ['MaxValue'], message.format('/'.join(map(str, tree + ['MaxValue'])))))
+                    )
+                    matches.append(
+                        RuleMatch(
+                            tree + ['MaxValue'],
+                            message.format('/'.join(map(str, tree + ['MaxValue']))),
+                        )
+                    )
             else:
                 message = 'Parameter for Cidr count have be of Type Number at {0}'
-                matches.append(RuleMatch(
-                    tree, message.format('/'.join(map(str, tree)))))
+                matches.append(
+                    RuleMatch(tree, message.format('/'.join(map(str, tree))))
+                )
 
         return matches
 
@@ -176,22 +254,28 @@ class Cidr(CloudFormationLintRule):
 
                     matches.extend(self.check_ip_block(ip_block_obj, tree[:] + [0]))
 
-                    new_count_parameters, new_matches = self.check_count(count_obj, tree[:] + [1])
+                    new_count_parameters, new_matches = self.check_count(
+                        count_obj, tree[:] + [1]
+                    )
                     count_parameters.extend(new_count_parameters)
                     matches.extend(new_matches)
 
-                    new_size_mask_parameters , new_matches = self.check_size_mask(size_mask_obj, tree[:] + [2])
+                    new_size_mask_parameters, new_matches = self.check_size_mask(
+                        size_mask_obj, tree[:] + [2]
+                    )
                     size_mask_parameters.extend(new_size_mask_parameters)
                     matches.extend(new_matches)
 
                 else:
                     message = 'Cidr should be a list of 2 or 3 elements for {0}'
-                    matches.append(RuleMatch(
-                        tree, message.format('/'.join(map(str, tree)))))
+                    matches.append(
+                        RuleMatch(tree, message.format('/'.join(map(str, tree))))
+                    )
             else:
                 message = 'Cidr should be a list of 2 or 3 elements for {0}'
-                matches.append(RuleMatch(
-                    tree, message.format('/'.join(map(str, tree)))))
+                matches.append(
+                    RuleMatch(tree, message.format('/'.join(map(str, tree))))
+                )
 
         for count_parameter in set(count_parameters):
             matches.extend(self.check_parameter_count(cfn, count_parameter))
