@@ -9,8 +9,10 @@ import cfnlint.helpers
 
 LOGGER = logging.getLogger('cfnlint')
 
+
 class GetAtt(CloudFormationLintRule):
     """Check if GetAtt values are correct"""
+
     id = 'E1010'
     shortdesc = 'GetAtt validation of parameters'
     description = 'Validates that GetAtt parameters are to valid resources and properties of those resources'
@@ -18,8 +20,8 @@ class GetAtt(CloudFormationLintRule):
     tags = ['functions', 'getatt']
 
     def __init__(self):
-        """Init """
-        super(GetAtt, self).__init__()
+        """Init"""
+        super().__init__()
         self.propertytypes = []
         self.resourcetypes = []
 
@@ -39,7 +41,9 @@ class GetAtt(CloudFormationLintRule):
         for getatt in getatts:
             if len(getatt[-1]) < 2:
                 message = 'Invalid GetAtt for {0}'
-                matches.append(RuleMatch(getatt, message.format('/'.join(map(str, getatt[:-1])))))
+                matches.append(
+                    RuleMatch(getatt, message.format('/'.join(map(str, getatt[:-1]))))
+                )
                 continue
             if isinstance(getatt[-1], str):
                 resname, restype = getatt[-1].split('.', 1)
@@ -62,19 +66,34 @@ class GetAtt(CloudFormationLintRule):
                                     RuleMatch(
                                         getatt,
                                         message.format(
-                                            ', '.join(map(str, valid_attribute_functions)),
-                                            '/'.join(map(str, getatt[:-1])))))
+                                            ', '.join(
+                                                map(str, valid_attribute_functions)
+                                            ),
+                                            '/'.join(map(str, getatt[:-1])),
+                                        ),
+                                    )
+                                )
                     else:
                         message = 'Invalid GetAtt structure {0} at {1}'
-                        matches.append(RuleMatch(getatt, message.format(
-                            getatt[-1], '/'.join(map(str, getatt[:-1])))))
+                        matches.append(
+                            RuleMatch(
+                                getatt,
+                                message.format(
+                                    getatt[-1], '/'.join(map(str, getatt[:-1]))
+                                ),
+                            )
+                        )
 
                     # setting restype to None as we can't validate that anymore
                     restype = None
                 else:
                     message = 'Invalid GetAtt structure {0} at {1}'
-                    matches.append(RuleMatch(getatt, message.format(
-                        getatt[-1], '/'.join(map(str, getatt[:-1])))))
+                    matches.append(
+                        RuleMatch(
+                            getatt,
+                            message.format(getatt[-1], '/'.join(map(str, getatt[:-1]))),
+                        )
+                    )
 
             # only check resname if its set.  if it isn't it is because of bad structure
             # and an error is already provided
@@ -83,23 +102,47 @@ class GetAtt(CloudFormationLintRule):
                     if restype is not None:
                         # Check for maps
                         restypeparts = restype.split('.')
-                        if restypeparts[0] in valid_getatts[resname] and len(restypeparts) >= 2:
-                            if valid_getatts[resname][restypeparts[0]].get('Type') != 'Map':
+                        if (
+                            restypeparts[0] in valid_getatts[resname]
+                            and len(restypeparts) >= 2
+                        ):
+                            if (
+                                valid_getatts[resname][restypeparts[0]].get('Type')
+                                != 'Map'
+                            ):
                                 message = 'Invalid GetAtt {0}.{1} for resource {2}'
-                                matches.append(RuleMatch(
-                                    getatt[:-1], message.format(resname, restype, getatt[1])))
+                                matches.append(
+                                    RuleMatch(
+                                        getatt[:-1],
+                                        message.format(resname, restype, getatt[1]),
+                                    )
+                                )
                             else:
                                 continue
-                        if restype not in valid_getatts[resname] and '*' not in valid_getatts[resname]:
+                        if (
+                            restype not in valid_getatts[resname]
+                            and '*' not in valid_getatts[resname]
+                        ):
                             message = 'Invalid GetAtt {0}.{1} for resource {2}'
-                            matches.append(RuleMatch(
-                                getatt[:-1], message.format(resname, restype, getatt[1])))
+                            matches.append(
+                                RuleMatch(
+                                    getatt[:-1],
+                                    message.format(resname, restype, getatt[1]),
+                                )
+                            )
                 else:
                     modules = cfn.get_modules()
                     if any(resname.startswith(s) for s in modules.keys()):
-                        LOGGER.debug('Will consider valid getatt %s because it references a resource within a module', resname)
+                        LOGGER.debug(
+                            'Will consider valid getatt %s because it references a resource within a module',
+                            resname,
+                        )
                     else:
                         message = 'Invalid GetAtt {0}.{1} for resource {2}'
-                        matches.append(RuleMatch(getatt, message.format(resname, restype, getatt[1])))
+                        matches.append(
+                            RuleMatch(
+                                getatt, message.format(resname, restype, getatt[1])
+                            )
+                        )
 
         return matches
