@@ -8,6 +8,7 @@ from cfnlint.rules import RuleMatch
 
 class If(CloudFormationLintRule):
     """Check if Condition exists"""
+
     id = 'E1028'
     shortdesc = 'Check Fn::If structure for validity'
     description = 'Check Fn::If to make sure its valid.  Condition has to be a string.'
@@ -27,18 +28,12 @@ class If(CloudFormationLintRule):
                 if_condition = ifs[0]
                 if len(ifs) != 3:
                     message = 'Fn::If must be a list of 3 elements.'
-                    matches.append(RuleMatch(
-                        iftree[:-1], message
-                    ))
+                    matches.append(RuleMatch(iftree[:-1], message))
                 if not isinstance(if_condition, str):
                     message = 'Fn::If first element must be a condition and a string.'
-                    matches.append(RuleMatch(
-                        iftree[:-1] + [0], message
-                    ))
+                    matches.append(RuleMatch(iftree[:-1] + [0], message))
             else:
                 message = 'Fn::If must be a list of 3 elements.'
-                matches.append(RuleMatch(
-                    iftree[:-1], message
-                ))
+                matches.append(RuleMatch(iftree[:-1], message))
 
         return matches
