@@ -8,9 +8,12 @@ from cfnlint.rules.common import approaching_number_limit
 
 class LimitNumber(CloudFormationLintRule):
     """Check maximum Parameter limit"""
+
     id = 'I2010'
     shortdesc = 'Parameter limit'
-    description = 'Check the number of Parameters in the template is approaching the upper limit'
+    description = (
+        'Check the number of Parameters in the template is approaching the upper limit'
+    )
     source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cloudformation-limits.html'
     tags = ['parameters', 'limits']
 
