@@ -8,6 +8,7 @@ from cfnlint.rules import RuleMatch
 
 class UpdateReplacePolicyDeletionPolicy(CloudFormationLintRule):
     """Check resources with UpdateReplacePolicy/DeletionPolicy have both"""
+
     id = 'W3011'
     shortdesc = 'Check resources with UpdateReplacePolicy/DeletionPolicy have both'
     description = 'Both UpdateReplacePolicy and DeletionPolicy are needed to protect resources from deletion'
@@ -19,11 +20,21 @@ class UpdateReplacePolicyDeletionPolicy(CloudFormationLintRule):
         matches = []
 
         for r_name, r_values in cfn.get_resources().items():
-            if r_values.get('Type') not in ['AWS::Lambda::Version', 'AWS::Lambda::LayerVersion']:
+            if r_values.get('Type') not in [
+                'AWS::Lambda::Version',
+                'AWS::Lambda::LayerVersion',
+            ]:
                 # pylint: disable=too-many-boolean-expressions
-                if r_values.get('DeletionPolicy') and r_values.get('DeletionPolicy') != 'Delete' and not r_values.get('UpdateReplacePolicy') or not r_values.get('DeletionPolicy') and r_values.get('UpdateReplacePolicy') and r_values.get('UpdateReplacePolicy') != 'Delete':
+                if (
+                    r_values.get('DeletionPolicy')
+                    and r_values.get('DeletionPolicy') != 'Delete'
+                    and not r_values.get('UpdateReplacePolicy')
+                    or not r_values.get('DeletionPolicy')
+                    and r_values.get('UpdateReplacePolicy')
+                    and r_values.get('UpdateReplacePolicy') != 'Delete'
+                ):
                     path = ['Resources', r_name]
-                    message = 'Both UpdateReplacePolicy and DeletionPolicy are needed to protect %s from deletion' % '/'.join(path)
+                    message = f'Both UpdateReplacePolicy and DeletionPolicy are needed to protect {"/".join(path)} from deletion'
                     matches.append(RuleMatch(path, message))
 
         return matches
